#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# about-dialog
# 
# tell the user about the project
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import os

from PyQt4 import QtCore
from PyQt4 import QtGui

# local
from environment import Environment


# ------------------------------------------------------------
# vars


ABOUT_TEXT = """
<html>

<style type="text/css">
    .header { margin-bottom: 24px; }
    .about_text { margin-bottom: 100px; margin-left: 64px; margin-right: 64px; }
    .logo { vertical-align: top; margin-bottom: 24px; }
    .footer { margin-top: 100px; }
</style>

<body bgcolor="#FFFFFF">
<div align="center">

<h1 class="header">
    <a href="http://www.opensecurity.at"><img src="image:opensecurity_logo.jpg"/></a><br/><br/>
    OpenSecurity Demo V0.1
</h1>

<div class="about_text" align="justify">
    Blah ...<br/>
</div>

<div class="logo">
    <a href="http://www.ait.ac.at"><img src="image:ait_logo_no_claim.png"/></a>
    <a href="http://www.x-net.at"><img src="image:x-net_logo.jpg"/></a>
    <a href="http://www.ikarussecurity.com"><img src="image:ikarus_logo.jpg"/></a>
</div>

<div class="logo">
    <a href="http://www.liqua.net"><img src="image:liqua_logo.jpg"/></a>
    <a href="http://www.linz.at"><img src="image:linz_logo.jpg"/></a>
    <a href="http://www.bmvit.gv.at"><img src="image:bmvit_logo.jpg"/></a>
</div>

<div class="logo">
    <a href="http://www.ffg.at"><img src="image:ffg_logo.jpg"/></a>
    <a href="http://www.kiras.at"><img src="image:kiras_logo.jpg"/></a>
</div>

<div class="footer" align="left">
    Copyright (C) 2013, AIT Austrian Institute of Technology<br/>
    AIT Austrian Institute of Technology GmbH<br/>
    Donau-City-Strasse 1 | 1220 Vienna | Austria<br/>
    <a href="http://www.ait.ac.at">http://www.ait.ac.at</a>
</div>

</div>
</body>
</html>
""";


# ------------------------------------------------------------
# code


class About(QtGui.QDialog):
    
    """Show some about stuff."""
    
    def __init__(self, parent = None, flags = QtCore.Qt.WindowFlags(0)):
        
        # super call and widget init
        super(About, self).__init__(parent, flags)
        
        # setup image search path
        QtCore.QDir.setSearchPaths("image", QtCore.QStringList(os.path.join(Environment('opensecurity').data_path, '..', 'gfx')));
        
        self.setWindowTitle('About OpenSecurity ...')
        self.setup_ui()
        

    def setup_ui(self):
        
        """Create the widgets."""
        
        lyMain = QtGui.QVBoxLayout(self)
        lyMain.setContentsMargins(8, 8, 8, 8)
        
        lbAbout = QtGui.QLabel()
        lbAbout.setStyleSheet("QWidget { background: white; color: black; };")
        lbAbout.setText(ABOUT_TEXT)
        lbAbout.setContentsMargins(12, 12, 12, 12)
        
        scAbout = QtGui.QScrollArea()
        scAbout.setWidget(lbAbout)
        scAbout.viewport().setStyleSheet("QWidget { background: white; color: black; };")
        lyMain.addWidget(scAbout)
        
        # buttons
        lyButton = QtGui.QHBoxLayout()
        lyMain.addLayout(lyButton)
        
        lyButton.addStretch(1)
        btnOk = QtGui.QPushButton('&Ok', self)
        btnOk.setMinimumWidth(100)
        lyButton.addWidget(btnOk)
        
        # connectors
        btnOk.clicked.connect(self.accept)
        
        # reduce to the max
        self.setMinimumSize(600, 400)
        self.resize(lyMain.minimumSize())

