#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# credentials-dialog
# 
# ask the user credentials
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

# local
from about import About

# ------------------------------------------------------------
# code


class Credentials(QtGui.QDialog):
    
    """Ask the user for credentials."""
    
    def __init__(self, text, parent = None, flags = QtCore.Qt.WindowFlags(0)):
        
        super(Credentials, self).__init__(parent, flags)
        self.setWindowTitle('OpenSecuirty Credentials Request')
        self.setup_ui()
        
        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        self.resize(self.geometry().width() * 1.25, self.geometry().height())
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
        
        # fix up text
        self.lbText.setText(text)
        

    def clicked_about(self):
        """clicked the about button"""
        dlgAbout = About()
        dlgAbout.exec_()
    

    def clicked_cancel(self):
        """clicked the cancel button"""
        self.reject()
    

    def clicked_ok(self):
        """clicked the ok button"""
        sys.stdout.write('{ ')
        sys.stdout.write('\'user\': \'')
        sys.stdout.write(self.edUser.text())
        sys.stdout.write('\', ')
        sys.stdout.write('\'password\': \'')
        sys.stdout.write(self.edPassword.text())
        sys.stdout.write('\' ')
        sys.stdout.write('}\n')
        self.accept()
    

    def setup_ui(self):
        
        """Create the widgets."""
        
        lyMain = QtGui.QVBoxLayout(self)
        lyMain.setContentsMargins(8, 8, 8, 8)
        
        # content area: left pixmap, right text
        lyContent = QtGui.QHBoxLayout()
        lyMain.addLayout(lyContent)
        
        # pixmap
        lbPix = QtGui.QLabel()
        lbPix.setPixmap(QtGui.QPixmapCache.find('opensecurity_icon_64'))
        lyContent.addWidget(lbPix, 0, QtCore.Qt.Alignment(QtCore.Qt.AlignTop + QtCore.Qt.AlignHCenter))
        lyContent.addSpacing(16)
        
        # text ...
        lyText = QtGui.QGridLayout()
        lyContent.addLayout(lyText, 1)
        self.lbText = QtGui.QLabel()
        lyText.addWidget(self.lbText, 0, 0, 1, 2)
        
        lbUser = QtGui.QLabel('&User:')
        lyText.addWidget(lbUser, 1, 0)
        self.edUser = QtGui.QLineEdit()
        lyText.addWidget(self.edUser, 1, 1)
        lbUser.setBuddy(self.edUser)
        
        lbPassword = QtGui.QLabel('&Password:')
        lyText.addWidget(lbPassword, 2, 0)
        self.edPassword = QtGui.QLineEdit()
        self.edPassword.setEchoMode(QtGui.QLineEdit.Password)
        lyText.addWidget(self.edPassword, 2, 1)
        lbPassword.setBuddy(self.edPassword)
        
        lyText.addWidget(QtGui.QWidget(), 3, 0, 1, 2)
        lyText.setColumnStretch(1, 1)
        lyText.setRowStretch(3, 1)
        
        lyMain.addStretch(1)
        
        # buttons
        lyButton = QtGui.QHBoxLayout()
        lyMain.addLayout(lyButton)
        
        lyButton.addStretch(1)
        btnOk = QtGui.QPushButton('&Ok', self)
        btnOk.setDefault(True)
        btnOk.setMinimumWidth(100)
        lyButton.addWidget(btnOk)
        btnCancel = QtGui.QPushButton('&Cancel', self)
        btnCancel.setMinimumWidth(100)
        lyButton.addWidget(btnCancel)
        btnAbout = QtGui.QPushButton('&About', self)
        btnAbout.setMinimumWidth(100)
        lyButton.addWidget(btnAbout)
        
        button_width = max(btnOk.width(), btnCancel.width(), btnAbout.width())
        btnOk.setMinimumWidth(button_width)
        btnCancel.setMinimumWidth(button_width)
        btnAbout.setMinimumWidth(button_width)
        
        # reduce to the max
        self.resize(lyMain.minimumSize())
        
        # connectors
        btnOk.clicked.connect(self.clicked_ok)
        btnCancel.clicked.connect(self.clicked_cancel)
        btnAbout.clicked.connect(self.clicked_about)
