#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# notification-dialog
# 
# show the user an opensecurity specific message box
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

# local
from about import About


# ------------------------------------------------------------
# code

class Notification(QtGui.QDialog):
    
    """Show the user an OpenSecurity specific notification."""
    
    TYPES = ['information', 'warning', 'critical']
        
    def __init__(self, msgtype, text, parent = None, flags = QtCore.Qt.WindowFlags(0)):
        
        # super call and widget init
        super(Notification, self).__init__(parent, flags)
        self.setWindowTitle('OpenSecuirty Notification')
        self.setup_ui(msgtype)
        
        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        self.resize(self.geometry().width() * 1.25, self.geometry().height())
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
        
        # fix up text
        if msgtype in Notification.TYPES:
            
            typetext = { 
                'information': 'OpenSecurity information', 
                'warning': '<b>OpenSecurity warning</b>', 
                'critical': '<b>OpenSecurity critical error</b>'
            }
            self.lbMsgType.setText(typetext[msgtype])
            
            captiontext = { 
                'information': 'OpenSecurity: Information', 
                'warning': 'OpenSecurity: Warning', 
                'critical': 'OpenSecurity: Critical'
            }
            self.setWindowTitle(captiontext[msgtype])
            
        else:
            raise ValueError('unknown msgtype')
        
        self.lbText.setText(text)
        

    def clicked_about(self):
        """clicked the about button"""
        dlgAbout = About()
        dlgAbout.exec_()
    

    def clicked_ok(self):
        """clicked the ok button"""
        self.accept()
    

    def setup_ui(self, msgtype):
        
        """Create the widgets."""
        
        lyMain = QtGui.QVBoxLayout(self)
        lyMain.setContentsMargins(8, 8, 8, 8)
        
        # content area: left pixmap, right text
        lyContent = QtGui.QHBoxLayout()
        lyMain.addLayout(lyContent)
        
        # pixmap
        lbPix = QtGui.QLabel()
        lbPix.setPixmap(QtGui.QPixmapCache.find('opensecurity_icon_64'))
        lyContent.addWidget(lbPix, 0, QtCore.Qt.Alignment(QtCore.Qt.AlignTop + QtCore.Qt.AlignHCenter))
        lyContent.addSpacing(16)
        
        # text ...
        lyText = QtGui.QVBoxLayout()
        lyContent.addLayout(lyText, 1)
        
        self.lbMsgType = QtGui.QLabel()
        lyText.addWidget(self.lbMsgType)
        self.lbText = QtGui.QLabel()
        lyText.addWidget(self.lbText)
        lyText.addStretch(1)
        
        lyMain.addStretch(1)
        
        # buttons
        lyButton = QtGui.QHBoxLayout()
        lyMain.addLayout(lyButton)
        
        lyButton.addStretch(1)
        btnOk = QtGui.QPushButton('&Ok', self)
        btnOk.setDefault(True)
        btnOk.setMinimumWidth(100)
        lyButton.addWidget(btnOk)
        btnAbout = QtGui.QPushButton('&About', self)
        btnAbout.setMinimumWidth(100)
        lyButton.addWidget(btnAbout)
        
        button_width = max(btnOk.width(), btnAbout.width())
        btnOk.setMinimumWidth(button_width)
        btnAbout.setMinimumWidth(button_width)
        
        # reduce to the max
        self.resize(lyMain.minimumSize())
        
        # connectors
        btnOk.clicked.connect(self.clicked_ok)
        btnAbout.clicked.connect(self.clicked_about)
