#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# opensecurity-dialog
# 
# an opensecurity dialog
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import argparse
import os
import subprocess
import sys
import urllib2

from PyQt4 import QtCore
from PyQt4 import QtGui

# local
from about import About
from environment import Environment


# ------------------------------------------------------------
# code


class OpenSecurityWait(QtGui.QDialog):

    """OpenSecurity: please wait ..."""
    
    def __init__(self, parent = None, flags = QtCore.Qt.WindowFlags(0)):
        super(OpenSecurityWait, self).__init__(parent, flags)
        self.setWindowTitle('OpenSecurity')
        self.setup_ui()
        
        
    def setup_ui(self):
        """Create the widgets."""
        
        lyMain = QtGui.QVBoxLayout(self)
        lyMain.setContentsMargins(8, 8, 8, 8)
        
        # content area: left pixmap, right text
        lbTitle = QtGui.QLabel('Creating secure subsystem. Please stand by ...')
        lyMain.addWidget(lbTitle)
        
        self.setMinimumSize(400, 50)
        self.resize(lyMain.minimumSize())


class OpenSecurityTrayIcon(QtGui.QSystemTrayIcon):
    
    """This is the OpenSecuirty Tray Icon"""

    def __init__(self, icon, parent=None):
        
        super(OpenSecurityTrayIcon, self).__init__(icon, parent)
        self.setup_ui()
        
        
    def clicked_about(self):
        """clicked about"""
        dlgAbout = About()
        dlgAbout.exec_()
    

    def clicked_browser(self):
        """wish for safe internet browsing"""
        
        # TODO: HARDCODED ADDRESS OF OPENSECURITYD
        
        # tell the user to wait
        dlg = OpenSecurityWait()
        dlg.show()
        QtGui.QApplication.instance().processEvents()
        
        try:
        
            # get a proper browsing VM
            browsing_vm = urllib2.urlopen('http://127.0.0.1:8080/browsing').readline()
            dlg_launch_image = os.path.join(sys.path[0], 'launch.pyw')
            #process_command = [sys.executable, dlg_launch_image, browsing_vm, '/usr/bin/iceweasel']
            process_command = [sys.executable, dlg_launch_image, browsing_vm, '/usr/bin/midori']
            print(process_command)
            process = subprocess.Popen(process_command, shell = False)
            
        except:
            dlg.hide()
            QtGui.QApplication.instance().processEvents()
            QtGui.QMessageBox.critical(None, 'Failed to invoke Safe Internet Browsing', 'OpenSecurity Error')
            
        dlg.hide()
        QtGui.QApplication.instance().processEvents()
            
            
    def clicked_exit(self):
        """clicked exit"""
        sys.exit(0)
    

    def clicked_launch_application(self):
        """clicked the launch an application"""
        dlg_launch_image = os.path.join(sys.path[0], 'launch.pyw')
        process_command = [sys.executable, dlg_launch_image]
        print(process_command)
        process = subprocess.Popen(process_command, shell = False)
            
            
    def setup_ui(self):
        """create the user interface
        As for the system tray this is 'just' the context menu.
        """
    
        # define the tray icon menu
        menu = QtGui.QMenu(self.parent())
        self.setContextMenu(menu)
        
        # add known apps
        cAcBrowser = menu.addAction(QtGui.QIcon(QtGui.QPixmapCache.find('opensecurity_icon_64')), 'Safe Internet Browsing')
        menu.addSeparator()
        
        # add standard menu items
        cAcLaunch = menu.addAction(QtGui.QIcon(QtGui.QPixmapCache.find('opensecurity_icon_64')), 'Lauch Application')
        menu.addSeparator()
        cAcAbout = menu.addAction("About")
        cAcExit = menu.addAction("Exit")
        
        cAcBrowser.triggered.connect(self.clicked_browser)
        cAcLaunch.triggered.connect(self.clicked_launch_application)
        cAcAbout.triggered.connect(self.clicked_about)
        cAcExit.triggered.connect(self.clicked_exit)
        
        
def main():
    
    app = QtGui.QApplication(sys.argv)

    # prebuild the pixmap cache: fetch all jpg, png and jpeg images and load them
    image_path = os.path.join(Environment("OpenSecurity").data_path, '..', 'gfx')
    for file in os.listdir(image_path):
        if file.lower().rpartition('.')[2] in ('jpg', 'png', 'jpeg'):
            QtGui.QPixmapCache.insert(file.lower().rpartition('.')[0], QtGui.QPixmap(os.path.join(image_path, file)))

    w = QtGui.QWidget()
    trayIcon = OpenSecurityTrayIcon(QtGui.QIcon(QtGui.QPixmapCache.find('opensecurity_icon_64')), w)

    trayIcon.show()
    app.setQuitOnLastWindowClosed(False)
    sys.exit(app.exec_())
   

# start
if __name__ == "__main__":
    main()

